@@ -205,10 +205,20 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	GdkColor color;
 
 	/*
-	 * Colors of text on the tutor window
+	 * Colors of text on the tutor window (note: ordering here matters, the first tag created is in the bottom!)
 	 */
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
 
+	gtk_text_buffer_create_tag (buf, "char_keep_wrap",
+		       	"background", TUTOR_CREAM,
+		       	"foreground", TUTOR_BLACK,
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);
+
+	gtk_text_buffer_create_tag (buf, "char_keep_wrap2",
+		       	"background", TUTOR_CREAM,
+		       	"foreground", TUTOR_BLACK,
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);
+
 	gtk_text_buffer_create_tag (buf, "char_untouched",
 		       	"background", TUTOR_CREAM,
 		       	"foreground", TUTOR_BLACK,
@@ -1040,24 +1050,15 @@ G_MODULE_EXPORT void
 on_virtual_key_changed (GtkEditable *edit, gpointer user_data)
 {
 	gunichar ch;
-	gboolean go_next = TRUE;
 
 	if (callbacks_shield)
 		return;
 
 	ch = g_utf8_get_char_validated (gtk_entry_get_text (GTK_ENTRY (edit)), -1);
 	if (ch == (gunichar)-2 || ch == (gunichar)-1 || ch == 0)
-	{
 		ch = L' ';
-		go_next = FALSE;
-	}
 
 	keyb_change_key (ch);
-
-	/*
-	if (go_next)
-		keyb_edit_next ();
-	*/
 }
 
 /* Confirm-dialog shared tasks
