@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -1034,6 +1034,7 @@ keyb_intro_step (gint step)
 	GtkLabel *tx1;
 	GtkLabel *tx2;
 	GtkTextBuffer *buffer;
+	GtkWidget *wg;
 
 	static gchar *intro01 = NULL;
 	static gchar *intro02 = NULL;
@@ -1048,9 +1049,9 @@ keyb_intro_step (gint step)
 
 	if (intro01 == NULL)
 	{
-		intro01 = g_strdup (_(
-	"Correct positioning of the hands and fingers is very important to efficient typing. "
-	"You will learn faster and type better if you follow the next recomendations."));
+		/* English typo: recomendations -> recommendations */
+		intro01 = g_strdup (_("Correct positioning of the hands and fingers is very important to efficient typing. "
+	"You will learn faster and type better if you follow the next recommendations."));
 		intro02 = g_strdup (_(
 	"The index-finger tips rest over each of the two keys which have a small raised mark, "
 	"in the center of the keyboard."));
@@ -1197,6 +1198,11 @@ keyb_intro_step (gint step)
 	}
 	g_free (intro00);
 
+	/* Blind people want no fancy autonomous buttons jumping around */
+	wg = get_wg ("checkbutton_speech");
+	if (GTK_WIDGET_VISIBLE (wg) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
+		hints_demo_fingers (0);
+
 	if (step == 0)
 		gtk_widget_set_sensitive (get_wg ("button_keyboard_previous"), FALSE);
 	else
@@ -1711,7 +1717,7 @@ hints_update_from_button (GtkButton *button)
 }
 
 /* Update the image of the window_hints
- * Map the character to the file which shows the finger associated with that key
+ * Maps the character to the file which shows the finger associated with that key
  */
 void
 hints_update_from_char (gunichar character)
@@ -1788,3 +1794,28 @@ hints_demo_fingers (guint msec)
 		source = g_main_context_find_source_by_id (NULL, id);
 	}
 }
+
+gchar *
+hints_finger_name_from_char (gunichar uch)
+{
+	gint i, j;
+
+	if (uch == UPSYM || uch == L'\n' || uch == L'\r')
+		return (hints_string_from_charcode ('9'));
+	if (uch == L' ')
+		return (hints_string_from_charcode ('5'));
+	
+	hints_init (); // if already initialized, do nothing
+
+	for (i = 3; i >= 0; i--)
+		for (j = 0; j < 15; j++)
+			if (uch == keyb.lochars[i][j])
+				return (hints_string_from_charcode (hints[i][j]));
+
+	for (i = 3; i >= 0; i--)
+		for (j = 0; j < 15; j++)
+			if (uch == keyb.upchars[i][j])
+				return (hints_string_from_charcode (hints[i][j]));
+
+	return (g_strdup (" "));
+}
