@@ -168,9 +168,6 @@ void
 top10_init_stats (gboolean locally)
 {
 	gint i;
-	Statistics *top10;
-
-	top10 = locally ? top10_local : top10_global;
 
 	for (i = 0; i < 10; i++)
 		top10_clean_stat (i, locally);
@@ -557,9 +554,6 @@ top10_read_stats (gboolean locally, gint lang)
 	gchar *stat_dir;
 	gboolean success;
 	GDir *home;
-	Statistics *top10;
-
-	top10 = locally ? top10_local : top10_global;
 
 	top10_init_stats (locally);
 
@@ -571,7 +565,7 @@ top10_read_stats (gboolean locally, gint lang)
 		g_message ("Could not read the scores file '%s'.\n Creating a blank one.", tmp);
 		top10_init_stats (locally);
 		top10_write_stats (locally, lang);
-		//top10_show_stat (top10);
+		//top10_show_stat (locally ? top10_local : top10_global);
 	}
 	g_free (tmp);
 
@@ -811,11 +805,9 @@ top10_global_update (gpointer data)
 	gchar *host;
 	gchar *command;
 	GtkImage *img;
-	gpointer gp;
 	CURL *curl;
 	FILE *fh;
 	
-	gp = data;
 	img = GTK_IMAGE (get_wg ("image_top10_update"));
 	top10_message (NULL);
 
@@ -900,13 +892,11 @@ top10_global_publish (gpointer data)
 	gchar *path;
 	gchar *username;
 	gchar *url;
-	gpointer gp;
 	GtkImage *img;
 	FILE *fh, *fh2;
 	struct stat fs;
 	CURL *curl;
 	
-	gp = data;
 	fs.st_size = 0;
 	img = GTK_IMAGE (get_wg ("image_top10_publish"));
 	top10_message (NULL);
