@@ -45,33 +45,33 @@ trans_code_to_country (gchar *code)
 	gchar *dummy = NULL;
 	static gchar map[COUNTRY_N][2][64] = {
 		{"xx","Esperantio"},
-		{"ar","العالم العربي"},
-		{"be","België"},
-		{"br","Brasil"},
-		{"ca","Canada"},
-		{"cz","Česká republika"},
-		{"dk","Danmark"},
-		{"de","Deutschland"},
-		{"eo","Esperantujo"},
-		{"es","España"},
+		{"ar","العالم العربي"},//
+		{"be","België"},//
+		{"br","Brasil"},//
+		{"ca","Canada"},//
+		{"cz","Česká republika"},//
+		{"dk","Danmark"},//
+		{"de","Deutschland"},//
+		{"eo","Esperantujo"},//
+		{"es","España"},//
 		{"eu","Euskal Herria"},
-		{"fr","France"},
-		{"gr","Ελλάδα"},
-		{"il","ישראל"},
-		{"hu","Magyarország"},
-		{"it","Italia"},
-		{"jp","日本 (Nippon)"},
-		{"kk","Қазақстан"},
-		{"nb","Norge"},
-		{"pl","Polska"},
-		{"pk","پاکستان"},
-		{"pt","Portugal"},
-		{"ru","Россия"},
-		{"se","Sverige"},
-		{"tr","Türkiye"},
-		{"ua","Україна"},
-		{"uk","United Kingdom"},
-		{"us","USA"},
+		{"fr","France"},//
+		{"gr","Ελλάδα"},//
+		{"il","ישראל"},//
+		{"hu","Magyarország"},//
+		{"it","Italia"},//
+		{"jp","日本 (Nippon)"},//
+		{"kk","Қазақстан"},//
+		{"no","Norge"},//
+		{"pl","Polska"},//
+		{"pk","پاکستان"},//
+		{"pt","Portugal"},//
+		{"ru","Россия"},//
+		{"se","Sverige"},//
+		{"tr","Türkiye"},//
+		{"ua","Україна"},//
+		{"uk","United Kingdom"},//
+		{"us","USA"}, //
 		{"cn","中华人民共和国"},
 		{"",""},
 		{"",""},
