@@ -87,6 +87,8 @@ tutor_set_query (TutorQuery query)
 gint
 tutor_get_correcting ()
 {
+	if (tutor.type != TT_FLUID)
+		return (FALSE);
 	return (tutor.correcting);
 }
 
@@ -408,17 +410,24 @@ tutor_update_start ()
 		fluid_draw_random_paragraphs ();
 	}
 
-	//gtk_widget_set_sensitive (get_wg ("button_tutor_restart"), FALSE);
-
 	/*
 	 * Apply tutor background color and font to the text
 	 */
-	gtk_text_buffer_get_bounds (buf, &start, &end);
-	gtk_text_iter_backward_char (&end);
-	gtk_text_buffer_apply_tag_by_name (buf, "char_untouched", &start, &end);
-	gtk_text_buffer_apply_tag_by_name (buf, "lesson_font", &start, &end);
 	gdk_color_parse (TUTOR_CREAM, &color);
 	gtk_widget_modify_base (get_wg ("text_tutor"), GTK_STATE_INSENSITIVE, &color);
+	gtk_text_buffer_get_bounds (buf, &start, &end);
+	gtk_text_iter_backward_char (&end);
+	gtk_text_buffer_apply_tag_by_name (buf, "lesson_font", &start, &end);
+	end = start;
+	while (gtk_text_iter_forward_word_end (&end))
+	{
+		gtk_text_buffer_apply_tag_by_name (buf, "char_keep_wrap", &start, &end);
+		start = end;
+		if (! gtk_text_iter_forward_char (&end))
+			break;
+		gtk_text_buffer_apply_tag_by_name (buf, "char_keep_wrap2", &start, &end);
+		start = end;
+	}
 	
 	tutor_message (_("Start typing when you are ready. "));
 
