@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -101,12 +101,20 @@ void tutor_char_distribution_count (gchar * text, Char_Distribution * dist);
 
 void tutor_draw_paragraph (gchar * text);
 
-void tutor_message (gchar * mesg);
-
-void tutor_beep (void);
-
 void tutor_load_list_other (gchar * file_name_end, GtkListStore * list);
 
 void tutor_other_rename (const gchar *new_tx, const gchar *old_tx);
 
+void tutor_message (gchar * mesg);
+
+void tutor_beep (void);
+
+gboolean tutor_delayed_finger_tip (gpointer unich);
+
+void tutor_speak_string (gchar *string, gboolean wait);
+
+void tutor_speak_char ();
+
+void tutor_speak_word ();
+
 #endif
